#!/usr/bin/perl
#
# This script merges two counts files as produced by ripper
# and produces on STDOUT a dataset suitable for gnuplot.

$file1 = shift;
$file2 = shift;

open(FILE1, "<" . $file1) || die "usage: $0 file1 file2\n";
open(FILE2, "<" . $file2) || die "usage: $0 file1 file2\n";

$line1 = <FILE1>;
$line1 =~ /: (.*)$/;
$title1 = $1 || die "$file1 has bad format\n";

$line2 = <FILE2>;
$line2 =~ /: (.*)$/;
$title2 = $1 || die "$file2 has bad format\n";

$line1 = <FILE1>;
$line1 =~ /: (.*)$/;
$numsamples1 = $1 || die "$file1 has bad format\n";

$line2 = <FILE2>;
$line2 =~ /: (.*)$/;
$numsamples2 = $1 || die "$file2 has bad format\n";

print STDOUT "# [$title1] vs [$title2]\n";

while( ($line1 = <FILE1>) && ($line2 = <FILE2>) ) {

  # skip comments
  next if( ($line1 =~ /^\#/) || ($line2 =~ /^\#/) );

  $line1 =~ /^(\d+) (\d+) (\d+) (\d+)/;
  $id1 = $1;
  $count1 = $2;
  $low1 = $3;
  $high1 = $4;

  $line2 =~ /^(\d+) (\d+) (\d+) (\d+)/;
  $id2 = $1;
  $count2 = $2;
  $low2 = $3;
  $high2 = $4;

  if( $id1 == $id2 ) {
    print STDOUT "$id1 " . 
      ($count1/$numsamples1) . " " . 
	($low1/$numsamples1) . " " . 
	  ($high1/$numsamples1) . " " . 
	    ($count2/$numsamples2) . " " . 
	      ($low2/$numsamples2) . " " . 
		($high2/$numsamples2) . "\n";
  } else {
    print STDERR "premature end of merge at line $.: ID numbers differ [$id1, $id2]\n";
    last;
  }
}


close(FILE1);
close(FILE2);

