/** @file urlfilter.h */
/* 
 * Copyright (C) 2002 Laird Breyer
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Author:   Laird Breyer <laird@lbreyer.com>
 */

#ifndef _URL_FILTER_H_
#define _URL_FILTER_H_
#include <string.h>
#include <stdexcept>
#include "content-type.h"

#define SLASHBIT 0x80

#define STRINGBUF_LEN0 511
#define STRINGBUF_LEN1 1023
#define STRINGBUF_LEN2 2047
#define STRINGBUF_LEN3 4095

/// Contains the parts of a URL as separate strings.
struct URLComponents {
  char scheme[STRINGBUF_LEN1+1];
  char netloc[STRINGBUF_LEN1+1];
  char query[STRINGBUF_LEN1+1];
  char params[STRINGBUF_LEN1+1];
  char path[STRINGBUF_LEN1+1];

  void Clear() { scheme[0] = netloc[0] = query[0] = params[0] = path[0] = 0; }
};

/// Knows how to parse a URL string and related functions
class URLFilter {
 public:
  URLFilter(bool rs);
  const char* DeindexURL(const char *anurl);
  const char* CompressURL(const char *anurl);
  void ParseURL(const char *anurl, char *schemebuf, 
		char *netlocbuf, char *querybuf,
		char *paramsbuf, char *pathbuf);
  void NormalizeURLPath(char *apath);
  ContentType ClassifyURLPath(const char *path);
  const char * FormatURL(const char *anurl, int anurl_len, 
			 URLComponents *baseurl, ContentType *foundtype) throw (domain_error);

 private:

  char scratchbuf0[STRINGBUF_LEN0+1];
  char scratchbuf1[STRINGBUF_LEN2+1];
  char scratchbuf2[STRINGBUF_LEN2+1];
  char scratchbuf3[STRINGBUF_LEN2+1];
  char scratchbuf4[STRINGBUF_LEN3+1];
  char scratchbuf5[STRINGBUF_LEN1+1];
  char scratchbuf6[STRINGBUF_LEN1+1];

  char comp_scratchbuf[STRINGBUF_LEN2+1];
  char parse_scratchbuf[STRINGBUF_LEN1+1];
  char deindex_scratchbuf[STRINGBUF_LEN2+1];

  struct {
    bool remove_html_suffix;
    bool rearrange_components;
  } flags;
};
#endif
